gchecky.data.CountryCode

Package gchecky :: Module data :: Class CountryCode |
[hide private]
[frames] | no frames]

# Class CountryCode

source code

    object --+
             |
    gxml.Field --+
                 |
       gxml.String --+
                     |
                    CountryCode

Instance Methods | [hide private]
validate(self, data) | source code
data2str(self, data) | source code
str2data(self, text) | source code
Inherited from `gxml.String`: `__init__` Inherited from `gxml.Field`: `__repr__`, `create_node_for_path`, `get_any_node_for_path`, `get_initial_value`, `get_nodes_for_path`, `get_one_node_for_path`, `load`, `save` Inherited from `gxml.Field` (private): `_traits` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Field`: `deconstruct_path`, `reconstruct_path`

Instance Variables | [hide private]
Inherited from `gxml.Field`: `default`, `empty`, `path`, `required`, `save_node_and_xml`, `values`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### validate(self, data) | source code
Decorators: `@apply_parent_validation(String, "Country Code: ")` Overrides: gxml.String.validate

### data2str(self, data) | source code
Overrides: gxml.String.data2str

### str2data(self, text) | source code
Overrides: gxml.String.str2data